@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2022, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -20,9 +20,6 @@ init
 json
     Create JSON files for one or more applications
 
-sampledata
-    Download the bokeh sample data sets
-
 secret
     Create a Bokeh secret key for use with Bokeh server
 
