@@ -3,5 +3,5 @@
 {% block code_to_run %}
   const docs_json = {{ docs_json }};
   const render_items = {{ render_items }};
-  root.Bokeh.embed.embed_items_notebook(docs_json, render_items);
+  void root.Bokeh.embed.embed_items_notebook(docs_json, render_items);
 {% endblock %}
