@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -96,12 +96,10 @@ Basic Properties
 .. autoclass:: MarkerType
 .. autoclass:: MinMaxBounds
 .. autoclass:: NonNegative
-.. autoclass:: NonNegativeInt
 .. autoclass:: Nothing
 .. autoclass:: Null
 .. autoclass:: Percent
 .. autoclass:: Positive
-.. autoclass:: PositiveInt
 .. autoclass:: RGB
 .. autoclass:: Regex
 .. autoclass:: Size
@@ -152,11 +150,11 @@ Special Properties
 .. autoclass:: InstanceDefault
 .. autoclass:: Include
 .. autoclass:: Nullable
-.. autoclass:: NonNullable
 .. autoclass:: NotSerialized
 .. autoclass:: Object
 .. autoclass:: Override
 .. autoclass:: Required
+.. autoclass:: TypeOfAttr
 
 Validation-only Properties
 --------------------------
@@ -242,6 +240,7 @@ __all__ = (
     'IntSpec',
     'Interval',
     'JSON',
+    'Len',
     'LineCapSpec',
     'LineJoinSpec',
     'List',
@@ -251,8 +250,6 @@ __all__ = (
     'MinMaxBounds',
     'NonEmpty',
     'NonNegative',
-    'NonNegativeInt',
-    'NonNullable',
     'NotSerialized',
     'Nothing',
     'Null',
@@ -266,7 +263,6 @@ __all__ = (
     'PandasGroupBy',
     'Percent',
     'Positive',
-    'PositiveInt',
     'RGB',
     'Readonly',
     'Regex',
@@ -286,6 +282,7 @@ __all__ = (
     'TextBaselineSpec',
     'TextLike',
     'Tuple',
+    'TypeOfAttr',
     'UnitsSpec',
     'UnsetValueError',
     'expr',
@@ -313,9 +310,12 @@ from .property.color import Color
 from .property.color import RGB
 from .property.color import ColorHex
 
+from .property.constraints import TypeOfAttr
+
 from .property.container import Array
 from .property.container import ColumnData
 from .property.container import Dict
+from .property.container import Len
 from .property.container import List
 from .property.container import NonEmpty
 from .property.container import Seq
@@ -370,17 +370,14 @@ from .property.json import JSON
 
 from .property.nothing import Nothing
 
-from .property.nullable import NonNullable
 from .property.nullable import Nullable
 
 from .property.numeric import Angle
 from .property.numeric import Byte
 from .property.numeric import Interval
 from .property.numeric import NonNegative
-from .property.numeric import NonNegativeInt
 from .property.numeric import Percent
 from .property.numeric import Positive
-from .property.numeric import PositiveInt
 from .property.numeric import Size
 
 from .property.override import Override
