@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -61,6 +61,7 @@ __all__ = (
     'Array',
     'ColumnData',
     'Dict',
+    'Len',
     'List',
     'NonEmpty',
     'RelativeDelta',
@@ -111,7 +112,7 @@ class Seq(ContainerProperty[T]):
 
     @classmethod
     def _is_seq_like(cls, value: Any) -> bool:
-        return (isinstance(value, (Container, Sized, Iterable))
+        return (isinstance(value, Container | Sized | Iterable)
                 and hasattr(value, "__getitem__") # NOTE: this is what makes it disallow set type
                 and not isinstance(value, Mapping))
 
@@ -202,11 +203,25 @@ class Dict(ContainerProperty[Any]):
 
         key_is_valid = self.keys_type.is_valid
         value_is_valid = self.values_type.is_valid
-        if isinstance(value, dict) and all(key_is_valid(key) and value_is_valid(val) for key, val in value.items()):
-            return
+        expected = f"expected a dict of type {self}"
 
-        msg = "" if not detail else f"expected an element of {self}, got {value!r}"
-        raise ValueError(msg)
+        if not isinstance(value, dict):
+            raise ValueError(f"{expected}, got a value of type {type(value)}" if detail else "")
+
+        bad_keys = [str(k) for k in value if not key_is_valid(k)]
+        bad_value_keys = [str(k) for (k, v) in value.items() if not value_is_valid(v)]
+        exception_header = f"{expected}, got a dict with"
+        bad_keys_str = f"invalid keys: {', '.join(bad_keys)}"
+        bad_value_keys_str = f"invalid values for keys: {', '.join(bad_value_keys)}"
+        err = None
+        if (has_bad_keys := any(bad_keys)) & (has_bad_key_values := any(bad_value_keys)):
+            err = ValueError(f"{exception_header} {bad_keys_str} and {bad_value_keys_str}")
+        elif has_bad_keys:
+            err = ValueError(f"{exception_header} {bad_keys_str}")
+        elif has_bad_key_values:
+            err = ValueError(f"{exception_header} {bad_value_keys_str}")
+        if err:
+            raise err if detail else ValueError("")
 
     def wrap(self, value):
         """ Some property types need to wrap their values in special containers, etc.
@@ -276,7 +291,7 @@ class Tuple(ContainerProperty):
     def validate(self, value: Any, detail: bool = True) -> None:
         super().validate(value, detail)
 
-        if isinstance(value, (tuple, list)) and len(self.type_params) == len(value):
+        if isinstance(value, tuple | list) and len(self.type_params) == len(value):
             if all(type_param.is_valid(item) for type_param, item in zip(self.type_params, value)):
                 return
 
@@ -336,6 +351,21 @@ class NonEmpty(SingleParameterizedProperty[TSeq]):
             msg = "" if not detail else "Expected a non-empty container"
             raise ValueError(msg)
 
+class Len(SingleParameterizedProperty[TSeq]):
+    """ Allows only containers of the given length. """
+
+    def __init__(self, type_param: TypeOrInst[TSeq], length: int, *, default: Init[TSeq] = Intrinsic,
+            help: str | None = None) -> None:
+        super().__init__(type_param, default=default, help=help)
+        self.length = length
+
+    def validate(self, value: Any, detail: bool = True) -> None:
+        super().validate(value, detail)
+
+        if len(value) != self.length:
+            msg = "" if not detail else f"Expected a container of length #{self.length}, got #{len(value)}"
+            raise ValueError(msg)
+
 #-----------------------------------------------------------------------------
 # Dev API
 #-----------------------------------------------------------------------------
