@@ -97,6 +97,7 @@ from typing import (
     Any,
     Callable,
     Generic,
+    TypeGuard,
     TypeVar,
 )
 
@@ -106,8 +107,6 @@ from .singletons import Undefined
 from .wrappers import PropertyValueColumnData, PropertyValueContainer
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeGuard
-
     from ...document.events import DocumentPatchedEvent
     from ..has_props import HasProps, Setter
     from .alias import Alias, DeprecatedAlias
@@ -204,7 +203,7 @@ This is a backwards compatibility alias for the {self.aliased_name!r} property.
 
     def __get__(self, obj: HasProps | None, owner: type[HasProps] | None) -> T:
         if obj is not None:
-            # Warn only when accesing descriptor's value, otherwise there would
+            # Warn only when accessing descriptor's value, otherwise there would
             # be a lot of spurious warnings from parameter resolution, etc.
             self._warn()
         return super().__get__(obj, owner)
@@ -399,13 +398,7 @@ class PropertyDescriptor(Generic[T]):
         Args:
             obj: (HasProps) : instance to set the property value on
 
-            json: (JSON-value) : value to set to the attribute to
-
-            models (dict or None, optional) :
-                Mapping of model ids to models (default: None)
-
-                This is needed in cases where the attributes to update also
-                have values that have references.
+            value: (JSON-value) : value to set to the attribute to
 
             setter (ClientSession or ServerSession or None, optional) :
                 This is used to prevent "boomerang" updates to Bokeh apps.
@@ -485,7 +478,7 @@ class PropertyDescriptor(Generic[T]):
     @classmethod
     def is_unstable(cls, value: Any) -> TypeGuard[Callable[[], Any]]:
         from .instance import InstanceDefault
-        return isinstance(value, (FunctionType, InstanceDefault))
+        return isinstance(value, FunctionType | InstanceDefault)
 
     def _get(self, obj: HasProps) -> T:
         """ Internal implementation of instance attribute access for the
@@ -787,9 +780,7 @@ class DataSpecPropertyDescriptor(PropertyDescriptor):
         Args:
             obj (HasProps) :
 
-            json (JSON-dict) :
-
-            models(seq[Model], optional) :
+            value (JSON-dict) :
 
             setter (ClientSession or ServerSession or None, optional) :
                 This is used to prevent "boomerang" updates to Bokeh apps.
