@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -69,7 +69,7 @@ class Object(Property[T]):
     _instance_type: type[T] | Callable[[], type[T]] | str
 
     def __init__(self, instance_type: type[T] | Callable[[], type[T]] | str, default: Init[T] = Undefined, help: str | None = None):
-        if not (isinstance(instance_type, (type, str)) or callable(instance_type)):
+        if not (isinstance(instance_type, type | str) or callable(instance_type)):
             raise ValueError(f"expected a type, fn() -> type, or string, got {instance_type}")
 
         if isinstance(instance_type, type):
