@@ -74,7 +74,7 @@ class DashPattern(Either):
     To indicate that dashing is turned off (solid lines), specify the empty
     list [].
 
-    .. _HTML5 Canvas dash specification style: http://www.w3.org/html/wg/drafts/2dcontext/html5_canvas/#dash-list
+    .. _HTML5 Canvas dash specification style: https://html.spec.whatwg.org/#dash-list
 
     """
 
@@ -100,7 +100,7 @@ class DashPattern(Either):
             try:
                 return self._dash_patterns[value]
             except KeyError:
-                return [int(x) for x in  value.split()]
+                return [int(x) for x in value.split()]
         else:
             return value
 
@@ -135,7 +135,7 @@ class HatchPatternType(Either):
         return self.__class__.__name__
 
 class Image(Property):
-    """ Accept image file types, e.g PNG, JPEG, TIFF, etc.
+    """ Accept image file types, e.g. PNG, JPEG, TIFF, etc.
 
     This property can be configured with:
 
