@@ -22,10 +22,9 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 from typing import (
-    TYPE_CHECKING,
     Any,
     Callable,
-    Union,
+    TypeAlias,
     cast,
 )
 
@@ -33,9 +32,6 @@ from typing import (
 from .check import ValidationIssue, Validator, ValidatorType
 from .issue import Error, Issue, Warning
 
-if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -49,7 +45,7 @@ __all__ = (
 # Private API
 #-----------------------------------------------------------------------------
 
-ValidationFunction: TypeAlias = Callable[..., Union[str, None]]
+ValidationFunction: TypeAlias = Callable[..., str | None]
 ValidationDecorator: TypeAlias = Callable[[ValidationFunction], Validator]
 
 def _validator(code_or_name: int | str | Issue, validator_type: ValidatorType) -> ValidationDecorator:
