@@ -187,7 +187,7 @@ class Document:
 
     @template.setter
     def template(self, template: Template) -> None:
-        if not isinstance(template, (Template, str)):
+        if not isinstance(template, Template | str):
             raise ValueError("document template must be Jinja2 template or a string")
         self._template = template
 
@@ -350,7 +350,7 @@ class Document:
         ''' Apply a JSON patch object and process any resulting events.
 
         Args:
-            patch (JSON-data) :
+            patch_json (JSON-data) :
                 The JSON-object containing the patch to apply.
 
             setter (ClientSession or ServerSession or None, optional) :
@@ -496,7 +496,7 @@ side of a communications channel while it was being removed on the other end.\
         hold will be applied according to the hold policy.
 
         Args:
-            hold ('combine' or 'collect', optional)
+            policy ('combine' or 'collect', optional)
                 Whether events collected during a hold should attempt to be
                 combined (default: 'combine')
 
@@ -716,7 +716,7 @@ side of a communications channel while it was being removed on the other end.\
         Args:
             selector (JSON-like query dictionary) : you can query by type or by
                 name,i e.g. ``{"type": HoverTool}``, ``{"name": "mycircle"}``
-                updates (dict) :
+            updates (dict) :
 
         Returns:
             None
@@ -813,19 +813,19 @@ side of a communications channel while it was being removed on the other end.\
 
         with self.models.freeze():
             while self.roots:
-                r = next(iter(self.roots))
-                self.remove_root(r)
-                roots.append(r)
+                root = next(iter(self.roots))
+                self.remove_root(root)
+                roots.append(root)
 
-        for r in roots:
-            if r.document is not None:
-                raise RuntimeError("Somehow we didn't detach %r" % (r))
+        for root in roots:
+            if root.document is not None:
+                raise RuntimeError(f"Somehow we didn't detach {root!r}")
 
         if len(self.models) != 0:
             raise RuntimeError(f"_all_models still had stuff in it: {self.models!r}")
 
-        for r in roots:
-            dest_doc.add_root(r)
+        for root in roots:
+            dest_doc.add_root(root)
 
         dest_doc.title = self.title
 
