@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -39,7 +39,7 @@ from ..core.templates import (
 )
 from ..document.document import DEFAULT_TITLE
 from ..settings import settings
-from ..util.serialization import make_id
+from ..util.serialization import make_globally_unique_css_safe_id
 from .util import RenderItem
 from .wrappers import wrap_in_onload, wrap_in_safely, wrap_in_script_tag
 
@@ -79,29 +79,34 @@ def div_for_render_item(item: RenderItem) -> str:
     '''
     return PLOT_DIV.render(doc=item, macros=MACROS)
 
-def html_page_for_render_items(bundle: Bundle | tuple[str, str], docs_json: dict[ID, DocJson],
-        render_items: list[RenderItem], title: str, template: Template | str | None = None,
-        template_variables: dict[str, Any] = {}) -> str:
+def html_page_for_render_items(
+    bundle: Bundle | tuple[str, str],
+    docs_json: dict[ID, DocJson],
+    render_items: list[RenderItem],
+    title: str | None,
+    template: Template | str | None = None,
+    template_variables: dict[str, Any] = {},
+) -> str:
     ''' Render an HTML page from a template and Bokeh render items.
 
     Args:
         bundle (tuple):
-            a tuple containing (bokehjs, bokehcss)
+            A tuple containing (bokeh_js, bokeh_css).
 
         docs_json (JSON-like):
-            Serialized Bokeh Document
+            Serialized Bokeh Document.
 
-        render_items (RenderItems)
-            Specific items to render from the document and where
+        render_items (RenderItems):
+            Specific items to render from the document and where.
 
-        title (str or None)
-            A title for the HTML page. If None, DEFAULT_TITLE is used
+        title (str or None):
+            A title for the HTML page. If None, DEFAULT_TITLE is used.
 
-        template (str or Template or None, optional) :
+        template (str or Template or None, optional):
             A Template to be used for the HTML page. If None, FILE is used.
 
         template_variables (dict, optional):
-            Any Additional variables to pass to the template
+            Any Additional variables to pass to the template.
 
     Returns:
         str
@@ -112,7 +117,7 @@ def html_page_for_render_items(bundle: Bundle | tuple[str, str], docs_json: dict
 
     bokeh_js, bokeh_css = bundle
 
-    json_id = make_id()
+    json_id = make_globally_unique_css_safe_id()
     json = escape(serialize_json(docs_json), quote=False)
     json = wrap_in_script_tag(json, "application/json", json_id)
 
