@@ -30,8 +30,8 @@ event object that triggered the callback.
 
 Alternatively it is possible to trigger Python code to run when events
 happen, in the context of a Bokeh application running on a Bokeh server.
-This can accomplished by passing an event class, and a callback function
-to the the :func:`~bokeh.model.Model.on_event` method. The callback should
+This can be accomplished by passing an event class, and a callback function
+to the :func:`~bokeh.model.Model.on_event` method. The callback should
 accept a single argument ``event``, which will be passed the concrete
 event object that triggered the callback.
 
@@ -76,11 +76,13 @@ from typing import (
 )
 
 # Bokeh imports
-from .core.serialization import Deserializer
+from .core.serialization import Deserializer, Serializable, Serializer
 
 if TYPE_CHECKING:
-    from .core.types import GeometryData
+    from .core.types import FactorType, GeometryData
     from .model import Model
+    from .models.annotations import Legend, LegendItem
+    from .models.axes import Axis
     from .models.plots import Plot
     from .models.widgets.buttons import AbstractButton
     from .models.widgets.inputs import TextInput
@@ -90,6 +92,7 @@ if TYPE_CHECKING:
 #-----------------------------------------------------------------------------
 
 __all__ = (
+    'AxisClick',
     'ButtonClick',
     'ConnectionLost',
     'DocumentEvent',
@@ -98,6 +101,7 @@ __all__ = (
     'Event',
     'LODEnd',
     'LODStart',
+    'LegendItemClick',
     'MenuItemClick',
     'ModelEvent',
     'MouseEnter',
@@ -144,7 +148,7 @@ class EventRep(TypedDict):
     name: str
     values: dict[str, Any]
 
-class Event:
+class Event(Serializable):
     ''' Base class for all Bokeh events.
 
     This base class is not typically useful to instantiate on its own.
@@ -167,6 +171,16 @@ class Event:
         if hasattr(cls, "event_name"):
             _CONCRETE_EVENT_CLASSES[cls.event_name] = cls
 
+    def event_values(self) -> dict[str, Any]:
+        return {}
+
+    def to_serializable(self, serializer: Serializer) -> BokehEventRep:
+        return BokehEventRep(
+            type="event",
+            name=self.event_name,
+            values=serializer.encode(self.event_values()),
+        )
+
     @classmethod
     def from_serializable(cls, rep: EventRep, decoder: Deserializer) -> Event:
         if not ("name" in rep and "values" in rep):
@@ -260,6 +274,31 @@ class ModelEvent(Event):
         '''
         self.model = model
 
+    def event_values(self) -> dict[str, Any]:
+        return dict(**super().event_values(), model=self.model)
+
+class AxisClick(ModelEvent):
+    ''' Announce a location where an axis was clicked.
+
+    For continuous numerical axes, the value will be a number. For log axes,
+    this number is the log decade.
+
+    For categorical axes, the value will be a categorical factor, i.e. a string
+    or a list of strings, representing the closest categorical factor that was
+    clicked.
+
+    '''
+    event_name = 'axis_click'
+
+    value: float | FactorType | None
+
+    def __init__(self, model: Axis | None, value: float | FactorType | None = None) -> None:
+        from .models import Axis
+        if model is not None and not isinstance(model, Axis):
+            clsname = self.__class__.__name__
+            raise ValueError(f"{clsname} event only applies to axis models")
+        super().__init__(model=model)
+        self.value = value
 
 class ButtonClick(ModelEvent):
     ''' Announce a button click event on a Bokeh button widget.
@@ -269,11 +308,21 @@ class ButtonClick(ModelEvent):
 
     def __init__(self, model: AbstractButton | None) -> None:
         from .models.widgets import AbstractButton, ToggleButtonGroup
-        if model is not None and not isinstance(model, (AbstractButton, ToggleButtonGroup)):
+        if model is not None and not isinstance(model, AbstractButton | ToggleButtonGroup):
             clsname = self.__class__.__name__
             raise ValueError(f"{clsname} event only applies to button and button group models")
         super().__init__(model=model)
 
+class LegendItemClick(ModelEvent):
+    ''' Announce a click event on a Bokeh legend item.
+
+    '''
+    event_name = 'legend_item_click'
+
+    def __init__(self, model: Legend, item: LegendItem) -> None:
+        self.item = item
+        super().__init__(model=model)
+
 class MenuItemClick(ModelEvent):
     ''' Announce a button click event on a Bokeh menu item.
 
@@ -399,7 +448,7 @@ class PointEvent(PlotEvent):
         y (float) : y-coordinate of the event in *data* space
 
     Note that data space coordinates are relative to the default range, not
-    any extra ranges, and the the screen space origin is at the top left of
+    any extra ranges, and the screen space origin is at the top left of
     the HTML canvas.
 
     '''
@@ -721,6 +770,11 @@ class RotateStart(PointEvent):
 # Dev API
 #-----------------------------------------------------------------------------
 
+class BokehEventRep(TypedDict):
+  type: Literal["event"]
+  name: str
+  values: Any
+
 #-----------------------------------------------------------------------------
 # Code
 #-----------------------------------------------------------------------------
