@@ -21,7 +21,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-from typing import TYPE_CHECKING, Any
+from typing import TYPE_CHECKING, Any, TypeGuard
 
 # Bokeh imports
 from ..models.ui import UIElement
@@ -31,8 +31,6 @@ from .saving import save
 from .state import curstate
 
 if TYPE_CHECKING:
-    from typing_extensions import TypeGuard
-
     from ..application.application import Application
     from ..application.handlers.function import ModifyDoc
     from ..util.browser import BrowserLike, BrowserTarget
