@@ -31,8 +31,8 @@ from typing import (
     Iterator,
     Literal,
     Sequence,
+    TypeAlias,
     TypeVar,
-    Union,
     overload,
 )
 
@@ -60,9 +60,6 @@ from .models import (
 from .util.dataclasses import dataclass
 from .util.warnings import warn
 
-if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -190,23 +187,56 @@ def layout(*args: UIElement, children: list[UIElement] | None = None, sizing_mod
     _children = _parse_children_arg(*args, children=children)
     return _create_grid(_children, sizing_mode, **kwargs)
 
+
+@overload
 def gridplot(
-        children: list[list[UIElement | None]], *,
-        sizing_mode: SizingModeType | None = None,
-        toolbar_location: LocationType | None = "above",
-        ncols: int | None = None,
-        width: int | None = None,
-        height: int | None = None,
-        toolbar_options: dict[ToolbarOptions, Any] | None = None,
-        merge_tools: bool = True) -> GridPlot:
+    children: list[UIElement | None],
+    *,
+    sizing_mode: SizingModeType | None = None,
+    toolbar_location: LocationType | None = "above",
+    ncols: int,
+    width: int | None = None,
+    height: int | None = None,
+    toolbar_options: dict[ToolbarOptions, Any] | None = None,
+    merge_tools: bool = True,
+) -> GridPlot:
+    ...
+
+
+@overload
+def gridplot(
+    children: list[list[UIElement | None]],
+    *,
+    sizing_mode: SizingModeType | None = None,
+    toolbar_location: LocationType | None = "above",
+    ncols: None = None,
+    width: int | None = None,
+    height: int | None = None,
+    toolbar_options: dict[ToolbarOptions, Any] | None = None,
+    merge_tools: bool = True,
+) -> GridPlot:
+    ...
+
+
+def gridplot(
+    children: list[UIElement | None] | list[list[UIElement | None]],
+    *,
+    sizing_mode: SizingModeType | None = None,
+    toolbar_location: LocationType | None = "above",
+    ncols: int | None = None,
+    width: int | None = None,
+    height: int | None = None,
+    toolbar_options: dict[ToolbarOptions, Any] | None = None,
+    merge_tools: bool = True,
+) -> GridPlot:
     ''' Create a grid of plots rendered on separate canvases.
 
     The ``gridplot`` function builds a single toolbar for all the plots in the
-    grid. ``gridplot`` is designed to layout a set of plots. For general
+    grid. ``gridplot`` is designed to lay out a set of plots. For general
     grid layout, use the :func:`~bokeh.layouts.layout` function.
 
     Args:
-        children (list of lists of |Plot|): An array of plots to display in a
+        children (list or list of lists of |Plot|): An array of plots to display in a
             grid, given as a list of lists of Plot objects. To leave a position
             in the grid empty, pass None for that position in the children list.
             OR list of |Plot| if called with ncols.
@@ -298,7 +328,7 @@ def gridplot(
                 raise ValueError("Only UIElement and LayoutDOM items can be inserted into a grid")
 
     def merge(cls: type[Tool], group: list[Tool]) -> Tool | ToolProxy | None:
-        if issubclass(cls, (SaveTool, CopyTool, ExamineTool, FullscreenTool)):
+        if issubclass(cls, SaveTool | CopyTool | ExamineTool | FullscreenTool):
             return cls()
         else:
             return None
@@ -311,13 +341,20 @@ def gridplot(
     if merge_tools:
         tools = group_tools(tools, merge=merge)
 
+    def map_to_proxy(active_tool: Tool | Literal["auto"] | None) -> ToolProxy | Tool:
+        if isinstance(active_tool, Tool):
+            for tool_or_proxy in tools:
+                if isinstance(tool_or_proxy, ToolProxy) and active_tool in tool_or_proxy.tools:
+                    return tool_or_proxy
+        return active_tool
+
     logos = [ toolbar.logo for toolbar in toolbars ]
     autohides = [ toolbar.autohide for toolbar in toolbars ]
-    active_drags = [ toolbar.active_drag for toolbar in toolbars ]
-    active_inspects = [ toolbar.active_inspect for toolbar in toolbars ]
-    active_scrolls = [ toolbar.active_scroll for toolbar in toolbars ]
-    active_taps = [ toolbar.active_tap for toolbar in toolbars ]
-    active_multis = [ toolbar.active_multi for toolbar in toolbars ]
+    active_drags = [ map_to_proxy(toolbar.active_drag) for toolbar in toolbars ]
+    active_inspects = [ map_to_proxy(toolbar.active_inspect) for toolbar in toolbars ] # TODO list[Tool]
+    active_scrolls = [ map_to_proxy(toolbar.active_scroll) for toolbar in toolbars ]
+    active_taps = [ map_to_proxy(toolbar.active_tap) for toolbar in toolbars ]
+    active_multis = [ map_to_proxy(toolbar.active_multi) for toolbar in toolbars ]
 
     V = TypeVar("V")
     def assert_unique(values: list[V], name: ToolbarOptions) -> V | UndefinedType:
@@ -558,7 +595,7 @@ def grid(children: Any = [], sizing_mode: SizingModeType | None = None, nrows: i
 #-----------------------------------------------------------------------------
 
 T = TypeVar("T", bound=Tool)
-MergeFn: TypeAlias = Callable[[type[T], list[T]], Union[Tool, ToolProxy, None]]
+MergeFn: TypeAlias = Callable[[type[T], list[T]], Tool | ToolProxy | None]
 
 def group_tools(tools: list[Tool | ToolProxy], *, merge: MergeFn[Tool] | None = None,
         ignore: set[str] | None = None) -> list[Tool | ToolProxy]:
@@ -600,9 +637,7 @@ def group_tools(tools: list[Tool | ToolProxy], *, merge: MergeFn[Tool] | None =
                     entries.remove(item)
             entries.remove(head)
 
-            if len(group) == 1:
-                computed.append(group[0])
-            elif merge is not None and (tool := merge(cls, group)) is not None:
+            if merge is not None and (tool := merge(cls, group)) is not None:
                 computed.append(tool)
             else:
                 computed.append(ToolProxy(tools=group))
