@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -27,6 +27,7 @@ from ..core.enums import (
     LatLon,
     LocationType,
     NumeralLanguage,
+    ResolutionType,
     RoundingFunction,
 )
 from ..core.has_props import abstract
@@ -39,16 +40,14 @@ from ..core.properties import (
     Enum,
     Instance,
     Int,
-    List,
     Nullable,
+    Seq,
     String,
 )
 from ..core.validation import error
 from ..core.validation.errors import MISSING_MERCATOR_DIMENSION
 from ..model import Model
-from ..util.deprecation import deprecated
 from ..util.strings import format_docstring
-from ..util.warnings import warn
 from .tickers import Ticker
 
 #-----------------------------------------------------------------------------
@@ -61,7 +60,6 @@ __all__ = (
     "CategoricalTickFormatter",
     "CustomJSTickFormatter",
     "DatetimeTickFormatter",
-    "FuncTickFormatter",
     "LogTickFormatter",
     "MercatorTickFormatter",
     "NumeralTickFormatter",
@@ -384,18 +382,6 @@ class CustomJSTickFormatter(TickFormatter):
         '''
     """)
 
-def FuncTickFormatter(*args, **kw):
-    from bokeh.util.deprecation import deprecated
-    deprecated((3, 0, 0), "FuncTickFormatter", "CustomJSTickFormatter")
-    return CustomJSTickFormatter(*args, **kw)
-
-def _deprecated_datetime_list_format(fmt: list[str]) -> str:
-    deprecated("Passing lists of formats for DatetimeTickFormatter scales was deprecated in Bokeh 3.0. Configure a single string format for each scale")
-    if len(fmt) == 0:
-        raise ValueError("Datetime format list must contain one element")
-    if len(fmt) > 1:
-        warn(f"DatetimeFormatter scales now only accept a single format. Using the first provided: {fmt[0]!r}")
-    return fmt[0]
 
 class DatetimeTickFormatter(TickFormatter):
     ''' A ``TickFormatter`` for displaying datetime values nicely across a
@@ -607,36 +593,60 @@ class DatetimeTickFormatter(TickFormatter):
         super().__init__(*args, **kwargs)
 
     microseconds = String(help=_DATETIME_TICK_FORMATTER_HELP("``microseconds``"),
-                          default="%fus").accepts(List(String), _deprecated_datetime_list_format)
+                          default="%fus")
 
     milliseconds = String(help=_DATETIME_TICK_FORMATTER_HELP("``milliseconds``"),
-                          default="%3Nms").accepts(List(String), _deprecated_datetime_list_format)
+                          default="%3Nms")
 
     seconds = String(help=_DATETIME_TICK_FORMATTER_HELP("``seconds``"),
-                     default="%Ss").accepts(List(String), _deprecated_datetime_list_format)
+                     default="%Ss")
 
     minsec = String(help=_DATETIME_TICK_FORMATTER_HELP("``minsec`` (for combined minutes and seconds)"),
-                    default=":%M:%S").accepts(List(String), _deprecated_datetime_list_format)
+                    default=":%M:%S")
 
     minutes = String(help=_DATETIME_TICK_FORMATTER_HELP("``minutes``"),
-                     default=":%M").accepts(List(String), _deprecated_datetime_list_format)
+                     default=":%M")
 
     hourmin = String(help=_DATETIME_TICK_FORMATTER_HELP("``hourmin`` (for combined hours and minutes)"),
-                     default="%H:%M").accepts(List(String), _deprecated_datetime_list_format)
+                     default="%H:%M")
 
     hours = String(help=_DATETIME_TICK_FORMATTER_HELP("``hours``"),
-                   default="%Hh").accepts(List(String), _deprecated_datetime_list_format)
+                   default="%Hh")
 
     days = String(help=_DATETIME_TICK_FORMATTER_HELP("``days``"),
-                  default="%m/%d").accepts(List(String), _deprecated_datetime_list_format)
+                  default="%m/%d")
 
     months = String(help=_DATETIME_TICK_FORMATTER_HELP("``months``"),
-                    default="%m/%Y").accepts(List(String), _deprecated_datetime_list_format)
+                    default="%m/%Y")
 
     years = String(help=_DATETIME_TICK_FORMATTER_HELP("``years``"),
-                   default="%Y").accepts(List(String), _deprecated_datetime_list_format)
+                   default="%Y")
 
-    strip_leading_zeros = Bool(default=True, help="Whether to strip any leading zeros in the formatted ticks")
+    strip_leading_zeros = Either(Bool, Seq(Enum(ResolutionType)), default=False, help="""
+    Whether to strip any leading zeros in the formatted ticks.
+
+    Valid values are:
+
+    * ``True`` or ``False`` (default) to set stripping across all resolutions.
+    * A sequence of resolution types, e.g. ``["microseconds", "milliseconds"]``, to enable
+      scale-dependent stripping of leading zeros.
+    """)
+
+    boundary_scaling = Bool(default=True, help="""
+    Whether to scale up ticks that are right at the boundary of the next higher resolution of time.
+    E.g. at the hours scale a tick sequence of ["00h", "06h", "12h", 18h", "00h"] will see a scale up of the "00h" ticks
+    as they are on boundary of the days scale: ["06/08", "06h", "12h", 18h", "06/09"]
+    """)
+
+    hide_repeats = Bool(default=False, help="""
+    Whether repeated formatted tick values will be suppressed.
+
+    For example, an initial set of ticks ``["06/07", "06/07", "06/07", "06/08",
+    "06/08"]`` will become ``["06/07", "", "", "06/08", ""]``. Only the base
+    label, without any additional context, is considered when determining
+    repeats. If the context itself is a ``DateTimeTickformatter``, then this
+    property may also be set for the context separately, if desired.
+    """)
 
     context = Nullable(Either(String, Instance("bokeh.models.formatters.DatetimeTickFormatter")), default=None, help="""
     A format for adding context to the tick or ticks specified by ``context_which``.
