@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -51,7 +51,11 @@ from ..core.properties import (
 from ..core.property.struct import Optional
 from ..core.property_aliases import GridSpacing, Pixels, TracksSizing
 from ..core.validation import error, warning
-from ..core.validation.errors import MIN_PREFERRED_MAX_HEIGHT, MIN_PREFERRED_MAX_WIDTH, REPEATED_LAYOUT_CHILD
+from ..core.validation.errors import (
+    MIN_PREFERRED_MAX_HEIGHT,
+    MIN_PREFERRED_MAX_WIDTH,
+    REPEATED_LAYOUT_CHILD,
+)
 from ..core.validation.warnings import (
     BOTH_CHILD_AND_ROOT,
     EMPTY_LAYOUT,
@@ -60,7 +64,8 @@ from ..core.validation.warnings import (
     FIXED_WIDTH_POLICY,
 )
 from ..model import Model
-from .ui.menus import Menu
+from .ui.panes import Pane
+from .ui.tooltips import Tooltip
 from .ui.ui_element import UIElement
 
 #-----------------------------------------------------------------------------
@@ -87,7 +92,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 @abstract
-class LayoutDOM(UIElement):
+class LayoutDOM(Pane):
     """ The base class for layoutable components.
 
     """
@@ -270,15 +275,6 @@ class LayoutDOM(UIElement):
     grid track align).
     """)
 
-    context_menu = Nullable(Instance(Menu), default=None, help="""
-    A menu to display when user right clicks on the component.
-
-    .. note::
-        To display a native context menu, the viewer will need to right-click
-        twice. The second click closes the Bokeh context menu and falls back
-        back the native one.
-    """)
-
     resizable = Either(Bool, Enum(Dimensions), default=False, help="""
     Whether the layout is interactively resizable, and if so in which dimensions.
     """)
@@ -313,18 +309,18 @@ class LayoutDOM(UIElement):
             return str(self)
 
     @error(MIN_PREFERRED_MAX_WIDTH)
-    def _min_preferred_max_width(self):
+    def _check_min_preferred_max_width(self):
         min_width = self.min_width if self.min_width is not None else 0
-        width     = self.width     if self.width     is not None else min_width
+        width     = self.width     if self.width     is not None and (self.sizing_mode == "fixed" or self.width_policy == "fixed") else min_width
         max_width = self.max_width if self.max_width is not None else width
 
         if not (min_width <= width <= max_width):
             return str(self)
 
     @error(MIN_PREFERRED_MAX_HEIGHT)
-    def _min_preferred_max_height(self):
+    def _check_min_preferred_max_height(self):
         min_height = self.min_height if self.min_height is not None else 0
-        height     = self.height     if self.height     is not None else min_height
+        height     = self.height     if self.height     is not None and (self.sizing_mode == "fixed" or self.height_policy == "fixed") else min_height
         max_height = self.max_height if self.max_height is not None else height
 
         if not (min_height <= height <= max_height):
@@ -434,7 +430,7 @@ class HBox(LayoutDOM):
 
     @error(REPEATED_LAYOUT_CHILD)
     def _check_repeated_layout_children(self):
-        children = [ item["child"] for item in self.items ]
+        children = [ item["child"] for item in self.children ]
         if len(children) != len(set(children)):
             return str(self)
 
@@ -459,7 +455,7 @@ class VBox(LayoutDOM):
 
     @error(REPEATED_LAYOUT_CHILD)
     def _check_repeated_layout_children(self):
-        children = [ item["child"] for item in self.items ]
+        children = [ item["child"] for item in self.children ]
         if len(children) != len(set(children)):
             return str(self)
 
@@ -554,6 +550,11 @@ class TabPanel(Model):
     The text title of the panel.
     """)
 
+    tooltip = Nullable(Instance(Tooltip), default=None, help="""
+    A tooltip with plain text or rich HTML contents, providing general help or
+    description of a widget's or component's function.
+    """)
+
     child = Instance(UIElement, help="""
     The child widget. If you need more children, use a layout widget, e.g. a ``Column``.
     """)
