@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2023, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -24,6 +24,7 @@ log = logging.getLogger(__name__)
 
 # Standard library imports
 from collections import Counter
+from math import nan
 
 # Bokeh imports
 from ..core.enums import PaddingUnits, StartEnd
@@ -41,7 +42,9 @@ from ..core.properties import (
     MinMaxBounds,
     Null,
     Nullable,
+    Override,
     Readonly,
+    Required,
     TimeDelta,
 )
 from ..core.validation import error
@@ -74,8 +77,25 @@ class Range(Model):
     def __init__(self, *args, **kwargs) -> None:
         super().__init__(*args, **kwargs)
 
+@abstract
+class NumericalRange(Range):
+    ''' A base class for numerical ranges.
 
-class Range1d(Range):
+    '''
+
+    # explicit __init__ to support Init signatures
+    def __init__(self, *args, **kwargs) -> None:
+        super().__init__(*args, **kwargs)
+
+    start = Required(Either(Float, Datetime, TimeDelta), help="""
+    The start of the range.
+    """)
+
+    end = Required(Either(Float, Datetime, TimeDelta), help="""
+    The end of the range.
+    """)
+
+class Range1d(NumericalRange):
     ''' A fixed, closed range [start, end] in a continuous scalar
     dimension.
 
@@ -99,14 +119,6 @@ class Range1d(Range):
 
         super().__init__(**kwargs)
 
-    start = Either(Float, Datetime, TimeDelta, default=0, help="""
-    The start of the range.
-    """)
-
-    end = Either(Float, Datetime, TimeDelta, default=1, help="""
-    The end of the range.
-    """)
-
     reset_start = Either(Null, Float, Datetime, TimeDelta, help="""
     The start of the range to apply after reset. If set to ``None`` defaults
     to the ``start`` value during initialization.
@@ -149,9 +161,12 @@ class Range1d(Range):
     maximum visible interval. Can be a ``TimeDelta``. Note that ``bounds`` can
     impose an implicit constraint on the maximum interval as well. """)
 
+    start = Override(default=0)
+
+    end = Override(default=1)
 
 @abstract
-class DataRange(Range):
+class DataRange(NumericalRange):
     ''' A base class for all data range types.
 
     '''
@@ -165,11 +180,14 @@ class DataRange(Range):
     defaults to all renderers on a plot.
     """)
 
+    start = Override(default=nan)
+
+    end = Override(default=nan)
 
 class DataRange1d(DataRange):
     ''' An auto-fitting range in a continuous scalar dimension.
 
-    By default the ``start`` and ``end`` of the range automatically
+    By default, the ``start`` and ``end`` of the range automatically
     assume min and max values of the data for associated renderers.
 
     '''
@@ -194,16 +212,6 @@ class DataRange1d(DataRange):
     as an absolute quantity. (default: ``"percent"``)
     """)
 
-    start = Either(Float, Datetime, TimeDelta, default=float("nan"), help="""
-    An explicitly supplied range start. If provided, will override
-    automatically computed start value.
-    """)
-
-    end = Either(Float, Datetime, TimeDelta, default=float("nan"), help="""
-    An explicitly supplied range end. If provided, will override
-    automatically computed end value.
-    """)
-
     bounds = Nullable(MinMaxBounds(accept_datetime=True), help="""
     The bounds that the range is allowed to go to. Typically used to prevent
     the user from panning/zooming/etc away from the data.
@@ -275,7 +283,6 @@ class DataRange1d(DataRange):
     bounds computations.
     """)
 
-
 class FactorRange(Range):
     ''' A Range of values for a categorical dimension.
 
@@ -291,13 +298,13 @@ class FactorRange(Range):
 
     .. code-block:: python
 
-        p.circle(x=["foo", "bar"], ...)
+        p.scatter(x=["foo", "bar"], ...)
 
     BokehJS will create a mapping from ``"foo"`` and ``"bar"`` to a numerical
     coordinate system called *synthetic coordinates*. In the simplest cases,
     factors are separated by a distance of 1.0 in synthetic coordinates,
     however the exact mapping from factors to synthetic coordinates is
-    affected by he padding properties as well as whether the number of levels
+    affected by the padding properties as well as whether the number of levels
     the factors have.
 
     Users typically do not need to worry about the details of this mapping,
@@ -308,7 +315,7 @@ class FactorRange(Range):
 
     .. code-block:: python
 
-        p.circle(x=[("foo", 0.3), ...], ...)
+        p.scatter(x=[("foo", 0.3), ...], ...)
 
     will position the first circle at an ``x`` position that is offset by
     adding 0.3 to the synthetic coordinate for ``"foo"``.
@@ -364,7 +371,7 @@ class FactorRange(Range):
         ])
 
     This property dictates how much padding to add between the three factors
-    in the `['foo', 'A']` group, and between the two factors in the the
+    in the `['foo', 'A']` group, and between the two factors in the
     [`bar`]
     """)
 
@@ -377,7 +384,7 @@ class FactorRange(Range):
 
         FactorRange(factors=[["foo", "1"], ["foo", "2"], ["bar", "1"]])
 
-    The top level groups correspond to ``"foo"` and ``"bar"``, and the
+    The top level groups correspond to ``"foo"`` and ``"bar"``, and the
     group padding will be applied between the factors ``["foo", "2"]`` and
     ``["bar", "1"]``
     """)
@@ -463,7 +470,7 @@ class FactorRange(Range):
     def _check_duplicate_factors(self):
         dupes = [item for item, count in Counter(self.factors).items() if count > 1]
         if dupes:
-            return "duplicate factors found: %s" % ', '.join(repr(x) for x in dupes)
+            return f"duplicate factors found: {', '.join(repr(x) for x in dupes)}"
 
 #-----------------------------------------------------------------------------
 # Dev API
