@@ -22,7 +22,7 @@ from typing import (
     TYPE_CHECKING,
     Any as TAny,
     Sequence,
-    Union,
+    TypeAlias,
     overload,
 )
 
@@ -49,16 +49,14 @@ from ..core.properties import (
     String,
 )
 from ..model import Model
-from ..util.deprecation import deprecated
 from ..util.serialization import convert_datetime_array
 from ..util.warnings import BokehUserWarning, warn
 from .callbacks import CustomJS
-from .filters import AllIndices, Filter, IntersectionFilter
+from .filters import AllIndices, Filter
 from .selections import Selection, SelectionPolicy, UnionRenderers
 
 if TYPE_CHECKING:
     import pandas as pd
-    from typing_extensions import TypeAlias
 
     from ..core.has_props import Setter
 
@@ -84,9 +82,9 @@ __all__ = (
 if TYPE_CHECKING:
     import numpy.typing as npt
 
-    DataDict: TypeAlias = dict[str, Union[Sequence[TAny], npt.NDArray[TAny], pd.Series, pd.Index]]
+    DataDict: TypeAlias = dict[str, Sequence[TAny] | npt.NDArray[TAny] | pd.Series | pd.Index]
 
-    Index: TypeAlias = Union[int, slice, tuple[Union[int, slice], ...]]
+    Index: TypeAlias = int | slice | tuple[int | slice, ...]
 
     Patches: TypeAlias = dict[str, list[tuple[Index, Any]]]
 
@@ -215,7 +213,7 @@ class ColumnDataSource(ColumnarDataSource):
     ).asserts(lambda _, data: len({len(x) for x in data.values()}) <= 1,
                  lambda obj, name, data: warn(
                     "ColumnDataSource's columns must be of the same length. " +
-                    "Current lengths: %s" % ", ".join(sorted(str((k, len(v))) for k, v in data.items())), BokehUserWarning))
+                    f"Current lengths: {', '.join(sorted(str((k, len(v))) for k, v in data.items()))}", BokehUserWarning))
 
     @overload
     def __init__(self, data: DataDict | pd.DataFrame | pd.core.groupby.GroupBy, **kwargs: TAny) -> None: ...
@@ -518,7 +516,7 @@ class ColumnDataSource(ColumnarDataSource):
 
         needs_length_check = True
 
-        if isinstance(new_data, (pd.Series, pd.DataFrame)):
+        if isinstance(new_data, pd.Series | pd.DataFrame):
             if isinstance(new_data, pd.Series):
                 new_data = new_data.to_frame().T
 
@@ -561,7 +559,7 @@ class ColumnDataSource(ColumnarDataSource):
         # slightly awkward that we have to call convert_datetime_array here ourselves
         # but the downstream code expects things to already be ms-since-epoch
         for key, values in new_data.items():
-            if pd and isinstance(values, (pd.Series, pd.Index)):
+            if pd and isinstance(values, pd.Series | pd.Index):
                 values = values.values
             old_values = self.data[key]
             # Apply the transformation if the new data contains datetimes
@@ -673,7 +671,7 @@ class ColumnDataSource(ColumnarDataSource):
         extra = set(patches.keys()) - set(self.data.keys())
 
         if extra:
-            raise ValueError("Can only patch existing columns (extra: %s)" % ", ".join(sorted(extra)))
+            raise ValueError(f"Can only patch existing columns (extra: {', '.join(sorted(extra))})")
 
         for name, patch in patches.items():
 
@@ -684,16 +682,16 @@ class ColumnDataSource(ColumnarDataSource):
                 # integer index, patch single value of 1d column
                 if isinstance(ind, int):
                     if ind > col_len or ind < 0:
-                        raise ValueError("Out-of bounds index (%d) in patch for column: %s" % (ind, name))
+                        raise ValueError(f"Out-of bounds index ({ind}) in patch for column: {name}")
 
                 # slice index, patch multiple values of 1d column
                 elif isinstance(ind, slice):
                     _check_slice(ind)
                     if ind.stop is not None and ind.stop > col_len:
-                        raise ValueError("Out-of bounds slice index stop (%d) in patch for column: %s" % (ind.stop, name))
+                        raise ValueError(f"Out-of bounds slice index stop ({ind.stop}) in patch for column: {name}")
 
                 # multi-index, patch sub-regions of "n-d" column
-                elif isinstance(ind, (list, tuple)):
+                elif isinstance(ind, list | tuple):
                     if len(ind) == 0:
                         raise ValueError("Empty (length zero) patch multi-index")
 
@@ -702,10 +700,10 @@ class ColumnDataSource(ColumnarDataSource):
 
                     ind_0 = ind[0]
                     if not isinstance(ind_0, int):
-                        raise ValueError("Initial patch sub-index may only be integer, got: %s" % ind_0)
+                        raise ValueError(f"Initial patch sub-index may only be integer, got: {ind_0}")
 
                     if ind_0 > col_len or ind_0 < 0:
-                        raise ValueError("Out-of bounds initial sub-index (%d) in patch for column: %s" % (ind, name))
+                        raise ValueError(f"Out-of bounds initial sub-index ({ind_0}) in patch for column: {name}")
 
                     if not isinstance(self.data[name][ind_0], np.ndarray):
                         raise ValueError("Can only sub-patch into columns with NumPy array items")
@@ -716,17 +714,17 @@ class ColumnDataSource(ColumnarDataSource):
                     elif isinstance(ind_0, slice):
                         _check_slice(ind_0)
                         if ind_0.stop is not None and ind_0.stop > col_len:
-                            raise ValueError("Out-of bounds initial slice sub-index stop (%d) in patch for column: %s" % (ind.stop, name))
+                            raise ValueError(f"Out-of bounds initial slice sub-index stop ({ind_0.stop}) in patch for column: {name}")
 
                     # Note: bounds of sub-indices after the first are not checked!
                     for subind in ind[1:]:
-                        if not isinstance(subind, (int, slice)):
-                            raise ValueError("Invalid patch sub-index: %s" % subind)
+                        if not isinstance(subind, int | slice):
+                            raise ValueError(f"Invalid patch sub-index: {subind}")
                         if isinstance(subind, slice):
                             _check_slice(subind)
 
                 else:
-                    raise ValueError("Invalid patch index: %s" % ind)
+                    raise ValueError(f"Invalid patch index: {ind}")
 
         self.data._patch(self.document, self, patches, setter)
 
@@ -736,9 +734,6 @@ class CDSView(Model):
     '''
 
     def __init__(self, *args: TAny, **kwargs: TAny) -> None:
-        if "source" in kwargs:
-            del kwargs["source"]
-            deprecated("CDSView.source is no longer needed, and is now ignored. In a future release, passing source will result an error.")
         super().__init__(*args, **kwargs)
 
     filter = Instance(Filter, default=InstanceDefault(AllIndices), help="""
@@ -756,27 +751,6 @@ class CDSView(Model):
         cds_view.filter &= ~IndexFilter(indices=[10, 11])
     """)
 
-    @property
-    def filters(self) -> list[Filter]:
-        deprecated("CDSView.filters was deprecated in bokeh 3.0. Use CDSView.filter instead.")
-        filter = self.filter
-        if isinstance(filter, IntersectionFilter):
-            return filter.operands
-        elif isinstance(filter, AllIndices):
-            return []
-        else:
-            return [filter]
-
-    @filters.setter
-    def filters(self, filters: list[Filter]) -> None:
-        deprecated("CDSView.filters was deprecated in bokeh 3.0. Use CDSView.filter instead.")
-        if len(filters) == 0:
-            self.filter = AllIndices()
-        elif len(filters) == 1:
-            self.filter = filters[0]
-        else:
-            self.filter = IntersectionFilter(operands=filters)
-
 class GeoJSONDataSource(ColumnarDataSource):
     '''
 
@@ -916,11 +890,11 @@ class AjaxDataSource(WebDataSource):
 
 def _check_slice(s: slice) -> None:
     if (s.start is not None and s.stop is not None and s.start > s.stop):
-        raise ValueError("Patch slices must have start < end, got %s" % s)
+        raise ValueError(f"Patch slices must have start < end, got {s}")
     if (s.start is not None and s.start < 0) or \
        (s.stop  is not None and s.stop < 0) or \
        (s.step  is not None and s.step < 0):
-        raise ValueError("Patch slices must have non-negative (start, stop, step) values, got %s" % s)
+        raise ValueError(f"Patch slices must have non-negative (start, stop, step) values, got {s}")
 
 #-----------------------------------------------------------------------------
 # Code
