@@ -51,6 +51,7 @@ from ...core.properties import (
     String,
     Tuple,
 )
+from ...events import ModelEvent
 from ...util.deprecation import deprecated
 from ..dom import HTML
 from ..formatters import TickFormatter
@@ -84,7 +85,6 @@ __all__ = (
 # Dev API
 #-----------------------------------------------------------------------------
 
-
 @abstract
 class InputWidget(Widget):
     ''' Abstract base class for input widgets.
@@ -107,6 +107,22 @@ class InputWidget(Widget):
 # General API
 #-----------------------------------------------------------------------------
 
+# TODO mark this as a one way event from server to client
+class ClearInput(ModelEvent):
+    """
+    Notifies the input widget that its input/value needs to be cleared.
+
+    This is specially useful for widgets whose value can't be simply cleared by
+    assigning to ``value`` (or equivalent) property.
+
+    """
+    event_name = "clear_input"
+
+    def __init__(self, model: InputWidget) -> None:
+        if not isinstance(model, InputWidget):
+            raise ValueError(f"{self.__class__.__name__} event only applies to input models, i.e. instances of bokeh.models.widgets.InputWidget")
+        super().__init__(model=model)
+
 class FileInput(InputWidget):
     ''' Present a file-chooser dialog to users and return the contents of the
     selected files.
@@ -117,7 +133,7 @@ class FileInput(InputWidget):
         super().__init__(*args, **kwargs)
 
     value = Readonly(Either(String, List(String)), help='''
-    The base64-enconded contents of the file or files that were loaded.
+    The base64-encoded contents of the file or files that were loaded.
 
     If `multiple` is set to False (default), this value is a single string with the contents
     of the single file that was chosen.
@@ -191,6 +207,30 @@ class FileInput(InputWidget):
     selection of more than one file at a time should be possible.
     """)
 
+    directory = Bool(default=False, help="""
+    Whether to allow selection of directories instead of files.
+
+    The filename will be relative paths to the uploaded directory.
+
+    .. note::
+        When a directory is uploaded it will give add a confirmation pop up.
+        The confirmation pop up cannot be disabled, as this is a security feature
+        in the browser.
+
+    .. note::
+        The `accept` parameter only works with file extension.
+        When using `accept` with `directory`, the number of files
+        reported will be the total amount of files, not the filtered.
+    """)
+
+
+    def clear(self) -> None:
+        """ Clear the contents of this file input widget.
+
+        """
+        doc = self.document
+        if doc is not None:
+            doc.callbacks.send_event(ClearInput(self))
 
 class NumericInput(InputWidget):
     ''' Numeric input widget.
