@@ -22,13 +22,12 @@ import itertools
 import re
 from dataclasses import dataclass
 from typing import (
-    TYPE_CHECKING,
     Any,
     Callable,
     Iterator,
     Literal,
     Sequence,
-    Union,
+    TypeAlias,
     cast,
 )
 
@@ -48,9 +47,6 @@ from ..models.tools import (
 )
 from ..util.warnings import warn
 
-if TYPE_CHECKING:
-    from typing_extensions import TypeAlias
-
 #-----------------------------------------------------------------------------
 # Globals and constants
 #-----------------------------------------------------------------------------
@@ -70,11 +66,11 @@ __all__ = (
 
 # TODO: str should be literal union of e.g. pan | xpan | ypan
 Auto: TypeAlias = Literal["auto"]
-ActiveDrag: TypeAlias = Union[Drag, Auto, str, None]
-ActiveInspect: TypeAlias = Union[list[InspectTool], InspectTool, Auto, str, None]
-ActiveScroll: TypeAlias = Union[Scroll, Auto, str, None]
-ActiveTap: TypeAlias = Union[Tap, Auto, str, None]
-ActiveMulti: TypeAlias = Union[GestureTool, Auto, str, None]
+ActiveDrag: TypeAlias = Drag | Auto | str | None
+ActiveInspect: TypeAlias = list[InspectTool] | InspectTool | Auto | str | None
+ActiveScroll: TypeAlias = Scroll | Auto | str | None
+ActiveTap: TypeAlias = Tap | Auto | str | None
+ActiveMulti: TypeAlias = GestureTool | Auto | str | None
 
 def process_active_tools(toolbar: Toolbar, tool_map: dict[str, Tool],
         active_drag: ActiveDrag, active_inspect: ActiveInspect, active_scroll: ActiveScroll,
@@ -83,7 +79,7 @@ def process_active_tools(toolbar: Toolbar, tool_map: dict[str, Tool],
 
     Args:
         toolbar (Toolbar): instance of a Toolbar object
-        tools_map (dict[str]): tool_map from _process_tools_arg
+        tool_map (dict[str]): tool_map from _process_tools_arg
         active_drag (str, None, "auto" or Tool): the tool to set active for drag
         active_inspect (str, None, "auto", Tool or Tool[]): the tool to set active for inspect
         active_scroll (str, None, "auto" or Tool): the tool to set active for scroll
