@@ -63,6 +63,7 @@ from typing import (
     Any,
     ClassVar,
     Generic,
+    TypeAlias,
     TypedDict,
     TypeVar,
 )
@@ -77,7 +78,7 @@ from ..core.types import ID
 from .exceptions import MessageError, ProtocolError
 
 if TYPE_CHECKING:
-    from typing_extensions import NotRequired, TypeAlias
+    from typing_extensions import NotRequired
 
     from ..client.websocket import WebSocketClientConnectionWrapper
 
@@ -207,8 +208,7 @@ class Message(Generic[Content]):
         ''' Associate a buffer header and payload with this message.
 
         Args:
-            buf_header (``JSON``) : a buffer header
-            buf_payload (``JSON`` or bytes) : a buffer payload
+            buffer (Buffer) : a buffer
 
         Returns:
             None
