@@ -22,10 +22,7 @@ from typing import (
     TYPE_CHECKING,
     Awaitable,
     Callable,
-    List,
     NewType,
-    Tuple,
-    Type,
 )
 
 # External imports
@@ -45,7 +42,7 @@ if TYPE_CHECKING:
 __all__ = (
     'AuthModule',
     'AuthProvider',
-    'NullAuth'
+    'NullAuth',
 )
 
 #-----------------------------------------------------------------------------
@@ -67,19 +64,17 @@ class AuthProvider:
     The properties ``logout_url`` and ``get_logout_handler`` are analogous to
     the corresponding login properties, and are optional.
 
-    .. autoclasstoc::
-
     '''
 
     def __init__(self) -> None:
         self._validate()
 
     @property
-    def endpoints(self) -> List[Tuple[str, Type[RequestHandler]]]:
+    def endpoints(self) -> list[tuple[str, type[RequestHandler]]]:
         ''' URL patterns for login/logout endpoints.
 
         '''
-        endpoints: List[Tuple[str, Type[RequestHandler]]] = []
+        endpoints: list[tuple[str, type[RequestHandler]]] = []
         if self.login_handler:
             assert self.login_url is not None
             endpoints.append((self.login_url, self.login_handler))
@@ -129,7 +124,7 @@ class AuthProvider:
         pass
 
     @property
-    def login_handler(self) -> Type[RequestHandler] | None:
+    def login_handler(self) -> type[RequestHandler] | None:
         ''' A request handler class for a login page.
 
         This property may return None, if ``login_url`` is supplied
@@ -152,7 +147,7 @@ class AuthProvider:
         pass
 
     @property
-    def logout_handler(self) -> Type[RequestHandler] | None:
+    def logout_handler(self) -> type[RequestHandler] | None:
         ''' A request handler class for a logout page.
 
         This property may return None.
@@ -211,8 +206,6 @@ class AuthModule(AuthProvider):
     The ``logout_handler`` property will return a ``LogoutHandler`` class from
     the module, or None otherwise.
 
-    .. autoclasstoc::
-
     '''
 
     def __init__(self, module_path: PathLike) -> None:
@@ -256,8 +249,6 @@ class NullAuth(AuthProvider):
 
     All of the properties of this provider return None.
 
-    .. autoclasstoc::
-
     '''
     @property
     def get_user(self):
