@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -36,6 +36,7 @@ from urllib.parse import urljoin
 # External imports
 from tornado.ioloop import PeriodicCallback
 from tornado.web import Application as TornadoApplication, StaticFileHandler
+from tornado.websocket import WebSocketClosedError
 
 if TYPE_CHECKING:
     from tornado.ioloop import IOLoop
@@ -280,8 +281,8 @@ class BokehTornado(TornadoApplication):
                  session_token_expiration: int = DEFAULT_SESSION_TOKEN_EXPIRATION,
                  **kwargs: Any):
 
-        from bokeh.application.handlers.document_lifecycle import DocumentLifecycleHandler
-        from bokeh.application.handlers.function import FunctionHandler
+        from ..application.handlers.document_lifecycle import DocumentLifecycleHandler
+        from ..application.handlers.function import FunctionHandler
 
         if callable(applications):
             applications = Application(FunctionHandler(applications))
@@ -697,7 +698,7 @@ class BokehTornado(TornadoApplication):
 
         '''
         if app_path not in self._applications:
-            raise ValueError("Application %s does not exist on this server" % app_path)
+            raise ValueError(f"Application {app_path} does not exist on this server")
         return self._applications[app_path].get_session(session_id)
 
     def get_sessions(self, app_path: str) -> list[ServerSession]:
@@ -713,7 +714,7 @@ class BokehTornado(TornadoApplication):
 
         '''
         if app_path not in self._applications:
-            raise ValueError("Application %s does not exist on this server" % app_path)
+            raise ValueError(f"Application {app_path} does not exist on this server")
         return list(self._applications[app_path].sessions)
 
     # Periodic Callbacks ------------------------------------------------------
@@ -783,8 +784,11 @@ class BokehTornado(TornadoApplication):
 
     def _keep_alive(self) -> None:
         log.trace("Running keep alive job") # type: ignore[attr-defined]
-        for c in self._clients:
-            c.send_ping()
+        for c in list(self._clients):
+            try:
+                c.send_ping()
+            except WebSocketClosedError:
+                self.client_lost(c)
 
 #-----------------------------------------------------------------------------
 # Dev API
