@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -41,7 +41,8 @@ from typing import TypedDict
 
 # External imports
 from sphinx.errors import SphinxError
-from sphinx.util import ensuredir, status_iterator
+from sphinx.util import ensuredir
+from sphinx.util.display import status_iterator
 
 # Bokeh imports
 from . import PARALLEL_SAFE
@@ -142,7 +143,7 @@ def config_inited_handler(app, config):
         if detail_file_path in extras:
             extras.remove(detail_file_path)
 
-        # if the gallery detail file is newer than the gallery file, assume it is up to date
+        # if the gallery detail file is newer than the gallery file, assume it is up-to-date
         if exists(detail_file_path) and getmtime(detail_file_path) > gallery_file_mtime:
             continue
 
@@ -157,8 +158,8 @@ def config_inited_handler(app, config):
 def get_details(app):
     details = []
     for subdir in app.config.bokeh_example_subdirs:
-        for name in os.listdir(join(_REPO_TOP, "examples", subdir)):
-            path = join("examples", subdir, name)
+        for name in os.listdir(_REPO_TOP / "examples" / subdir):
+            path = PurePath("examples", subdir, name).as_posix()
             if not name.startswith('_') and name.endswith('.py') and path not in app.config.bokeh_sampledata_xref_skiplist:
                 name = name.replace('.py', '')
                 rst_file_path = join(subdir, f'{name}.rst')
