@@ -1,5 +1,5 @@
 # -----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -78,14 +78,15 @@ class BokehReleases(BokehDirective):
 
         rst = []
 
-        for v in versions:
+        for version in versions:
             try:
-                hashes = get_sri_hashes_for_version(v)
-                rst.append(RELEASE_DETAIL.render(version=v, table=sorted(hashes.items())))
-            except KeyError:
-                if v == __version__:
-                    raise RuntimeError(f"Missing SRI Hash for full release version {v!r}")
-                rst.append(RELEASE_DETAIL.render(version=v, table=[]))
+                hashes = get_sri_hashes_for_version(version)
+                table = sorted(hashes.items())
+            except ValueError:
+                if version == __version__:
+                    raise RuntimeError(f"Missing SRI Hash for full release version {version!r}")
+                table = []
+            rst.append(RELEASE_DETAIL.render(version=version, table=table))
 
         return self.parse("\n".join(rst), "<bokeh-releases>")
 
