@@ -29,7 +29,6 @@ import yaml
 # Bokeh imports
 from ..core.has_props import HasProps
 from ..core.types import PathLike
-from ..util.deprecation import deprecated
 
 if TYPE_CHECKING:
     from ..model import Model
@@ -72,7 +71,7 @@ class Theme:
     The ``Theme`` class can be constructed either from a YAML file or from a
     JSON dict (but not both). Examples of both formats are shown below.
 
-    The plotting API's defaults override some theme properties. Namely:
+    The plotting API defaults override some theme properties. Namely:
     `fill_alpha`, `fill_color`, `line_alpha`, `line_color`, `text_alpha` and
     `text_color`. Those properties should therefore be set explicitly when
     using the plotting API.
@@ -83,7 +82,7 @@ class Theme:
 
     Raises:
         ValueError
-            If neither ``filename`` or ``json`` is supplied.
+            If neither ``filename`` nor ``json`` is supplied.
 
     Examples:
 
@@ -179,12 +178,6 @@ class Theme:
             if not isinstance(value, dict):
                 raise ValueError(f"theme problem: attrs.{key} should be a dictionary of properties, not {value!r}")
 
-        # Special-case to allow Figure to continue working with a deprecation
-        if "Figure" in self._json['attrs']:
-            self._json['attrs']['figure'] = self._json['attrs']['Figure']
-            del self._json['attrs']['Figure']
-            deprecated((3, 0, 0), "Use of 'Figure' as a key in Theme attributes", "'figure' (lower-case) as a key")
-
         self._line_defaults = self._json.get('line_defaults', _empty_dict)
         self._fill_defaults = self._json.get('fill_defaults', _empty_dict)
         self._text_defaults = self._json.get('text_defaults', _empty_dict)
