@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -60,6 +60,14 @@ functionality.
 .. automodule:: bokeh.util.hex
   :members:
 
+.. _bokeh.util.info:
+
+``bokeh.util.info``
+----------------------
+
+.. automodule:: bokeh.util.info
+  :members:
+
 .. _bokeh.util.logconfig:
 
 ``bokeh.util.logconfig``
