@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -86,7 +86,9 @@ class Static(Subcommand):
             if server.address is not None and server.address != '':
                 address_string = ' address ' + server.address
 
-            log.info("Starting Bokeh static server on port %d%s", server.port, address_string)
+            log.info(f"Starting Bokeh static server at {server.port}{address_string}")
+            log.debug(f"Serving static files from: {settings.bokehjs_path()}")
+
             server.run_until_shutdown()
 
 #-----------------------------------------------------------------------------
