@@ -37,9 +37,9 @@ from typing import (
     Iterable,
     Literal,
     NoReturn,
+    TypeAlias,
     TypedDict,
     TypeVar,
-    Union,
     overload,
 )
 from weakref import WeakSet
@@ -51,7 +51,7 @@ else:
     from functools import lru_cache
 
 if TYPE_CHECKING:
-    from typing_extensions import Self
+    from typing_extensions import NotRequired, Self
 
 # Bokeh imports
 from ..settings import settings
@@ -71,8 +71,6 @@ from .serialization import (
 from .types import ID
 
 if TYPE_CHECKING:
-    from typing_extensions import NotRequired, TypeAlias
-
     from ..client.session import ClientSession
     from ..server.session import ServerSession
     from .property.bases import Property
@@ -99,7 +97,7 @@ __all__ = (
 #-----------------------------------------------------------------------------
 
 if TYPE_CHECKING:
-    Setter: TypeAlias = Union[ClientSession, ServerSession]
+    Setter: TypeAlias = ClientSession | ServerSession
 
 C = TypeVar("C", bound=type["HasProps"])
 
@@ -426,15 +424,9 @@ class HasProps(Serializable, metaclass=MetaHasProps):
         ''' Set a property value on this object from JSON.
 
         Args:
-            name: (str) : name of the attribute to set
+            name (str) : name of the attribute to set
 
-            json: (JSON-value) : value to set to the attribute to
-
-            models (dict or None, optional) :
-                Mapping of model ids to models (default: None)
-
-                This is needed in cases where the attributes to update also
-                have values that have references.
+            value (JSON-value) : value to set to the attribute to
 
             setter(ClientSession or ServerSession or None, optional) :
                 This is used to prevent "boomerang" updates to Bokeh apps.
