@@ -26,8 +26,8 @@ from typing import (
     Any,
     Literal,
     Sequence,
+    TypeAlias,
     TypedDict,
-    Union,
     cast,
     overload,
 )
@@ -58,7 +58,6 @@ from .wrappers import wrap_in_onload
 
 if TYPE_CHECKING:
     from jinja2 import Template
-    from typing_extensions import TypeAlias
 
     from ..core.types import ID
     from ..document.document import DocJson
@@ -74,14 +73,14 @@ __all__ = (
     'json_item',
 )
 
-ModelLike: TypeAlias = Union[Model, Document]
-ModelLikeCollection: TypeAlias = Union[Sequence[ModelLike], dict[str, ModelLike]]
+ModelLike: TypeAlias = Model | Document
+ModelLikeCollection: TypeAlias = Sequence[ModelLike] | dict[str, ModelLike]
 
 #-----------------------------------------------------------------------------
 # General API
 #-----------------------------------------------------------------------------
 
-ThemeLike: TypeAlias = Union[None, Theme, type[FromCurdoc]]
+ThemeLike: TypeAlias = None | Theme | type[FromCurdoc]
 
 def autoload_static(model: Model | Document, resources: Resources, script_path: str) -> tuple[str, str]:
     ''' Return JavaScript code and a script tag that can be used to embed
@@ -134,21 +133,21 @@ def autoload_static(model: Model | Document, resources: Resources, script_path:
     return js, tag
 
 @overload
-def components(models: Model, wrap_script: bool = ..., # type: ignore[overload-overlap] # XXX: mypy bug
+def components(models: Model, wrap_script: bool = ...,
     wrap_plot_info: Literal[True] = ..., theme: ThemeLike = ...) -> tuple[str, str]: ...
 @overload
 def components(models: Model, wrap_script: bool = ..., wrap_plot_info: Literal[False] = ...,
     theme: ThemeLike = ...) -> tuple[str, RenderRoot]: ...
 
 @overload
-def components(models: Sequence[Model], wrap_script: bool = ..., # type: ignore[overload-overlap] # XXX: mypy bug
+def components(models: Sequence[Model], wrap_script: bool = ...,
     wrap_plot_info: Literal[True] = ..., theme: ThemeLike = ...) -> tuple[str, Sequence[str]]: ...
 @overload
 def components(models: Sequence[Model], wrap_script: bool = ..., wrap_plot_info: Literal[False] = ...,
     theme: ThemeLike = ...) -> tuple[str, Sequence[RenderRoot]]: ...
 
 @overload
-def components(models: dict[str, Model], wrap_script: bool = ..., # type: ignore[overload-overlap] # XXX: mypy bug
+def components(models: dict[str, Model], wrap_script: bool = ...,
     wrap_plot_info: Literal[True] = ..., theme: ThemeLike = ...) -> tuple[str, dict[str, str]]: ...
 @overload
 def components(models: dict[str, Model], wrap_script: bool = ..., wrap_plot_info: Literal[False] = ...,
@@ -454,16 +453,16 @@ def _check_models_or_docs(models: ModelLike | ModelLikeCollection) -> ModelLikeC
     input_type_valid = False
 
     # Check for single item
-    if isinstance(models, (Model, Document)):
+    if isinstance(models, Model | Document):
         models = [models]
 
     # Check for sequence
-    if isinstance(models, Sequence) and all(isinstance(x, (Model, Document)) for x in models):
+    if isinstance(models, Sequence) and all(isinstance(x, Model | Document) for x in models):
         input_type_valid = True
 
     if isinstance(models, dict) and \
         all(isinstance(x, str) for x in models.keys()) and \
-        all(isinstance(x, (Model, Document)) for x in models.values()):
+        all(isinstance(x, Model | Document) for x in models.values()):
         input_type_valid = True
 
     if not input_type_valid:
