@@ -1,5 +1,5 @@
 #-----------------------------------------------------------------------------
-# Copyright (c) 2012 - 2024, Anaconda, Inc., and Bokeh Contributors.
+# Copyright (c) Anaconda, Inc., and Bokeh Contributors.
 # All rights reserved.
 #
 # The full license is in the file LICENSE.txt, distributed with this software.
@@ -18,8 +18,7 @@ log = logging.getLogger(__name__)
 #-----------------------------------------------------------------------------
 
 # Standard library imports
-import os
-from os.path import join
+from os import fspath
 from subprocess import Popen
 
 # Bokeh imports
@@ -38,8 +37,14 @@ __all__ = ("init", "build")
 # General API
 #-----------------------------------------------------------------------------
 
-def init(base_dir: PathLike, *, interactive: bool = False,
-         bokehjs_version: str | None = None, debug: bool = False) -> bool:
+def init(
+    base_dir: PathLike,
+    *,
+    interactive: bool = False,
+    verbose: bool = False,
+    bokehjs_version: str | None = None,
+    debug: bool = False,
+) -> bool:
     """ Initialize a directory as a new bokeh extension.
 
     Arguments:
@@ -47,6 +52,8 @@ def init(base_dir: PathLike, *, interactive: bool = False,
 
         interactive (bool) : Guide the user step-by-step.
 
+        verbose (bool) : Display detailed build information.
+
         bokehjs_version (str) : Use a specific version of bokehjs.
 
         debug (bool) : Allow for remote debugging.
@@ -58,13 +65,15 @@ def init(base_dir: PathLike, *, interactive: bool = False,
     args: list[str] = []
     if interactive:
         args.append("--interactive")
+    if verbose:
+        args.append("--verbose")
     if bokehjs_version:
         args.extend(["--bokehjs-version", bokehjs_version])
     proc = _run_command("init", base_dir, args, debug)
     return proc.returncode == 0
 
 
-def build(base_dir: PathLike, *, rebuild: bool = False, debug: bool = False) -> bool:
+def build(base_dir: PathLike, *, rebuild: bool = False, verbose: bool = False, debug: bool = False) -> bool:
     """ Build a bokeh extension in the given directory.
 
     Arguments:
@@ -72,6 +81,8 @@ def build(base_dir: PathLike, *, rebuild: bool = False, debug: bool = False) ->
 
         rebuild (bool) : Ignore caches and rebuild from scratch.
 
+        verbose (bool) : Display detailed build information.
+
         debug (bool) : Allow for remote debugging.
 
     Returns:
@@ -81,6 +92,8 @@ def build(base_dir: PathLike, *, rebuild: bool = False, debug: bool = False) ->
     args: list[str] = []
     if rebuild:
         args.append("--rebuild")
+    if verbose:
+        args.append("--verbose")
     proc = _run_command("build", base_dir, args, debug)
     return proc.returncode == 0
 
@@ -93,19 +106,19 @@ def build(base_dir: PathLike, *, rebuild: bool = False, debug: bool = False) ->
 #-----------------------------------------------------------------------------
 
 def _run_command(command: str, base_dir: PathLike, args: list[str], debug: bool = False) -> Popen[bytes]:
-    bokehjs_dir = settings.bokehjsdir()
+    bokehjs_dir = settings.bokehjs_path()
 
     if debug:
-        compiler_script = join(bokehjs_dir, "js", "compiler", "main.js")
+        compiler_script = bokehjs_dir / "js" / "compiler" / "main.js"
     else:
-        compiler_script = join(bokehjs_dir, "js", "compiler.js")
+        compiler_script = bokehjs_dir / "js" / "compiler.js"
 
     cmd = [
         "--no-deprecation",
-        compiler_script,
+        fspath(compiler_script),
         command,
-        "--base-dir", os.fspath(base_dir),
-        "--bokehjs-dir", bokehjs_dir,
+        "--base-dir", fspath(base_dir),
+        "--bokehjs-dir", fspath(bokehjs_dir),
         "--bokeh-version", __version__,
     ]
 
