@@ -134,6 +134,7 @@ class figure(Plot, GlyphAPI):
         * :func:`~bokeh.plotting.figure.line`
         * :func:`~bokeh.plotting.figure.multi_line`
         * :func:`~bokeh.plotting.figure.multi_polygons`
+        * :func:`~bokeh.plotting.figure.ngon`
         * :func:`~bokeh.plotting.figure.patch`
         * :func:`~bokeh.plotting.figure.patches`
         * :func:`~bokeh.plotting.figure.plus`
@@ -369,7 +370,7 @@ class figure(Plot, GlyphAPI):
         Examples:
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
-            *2016* and *2017*, then the following call to ``harea_stack`` will
+            *2016* and *2017*, then the following call to ``harea_stack``
             will create two ``HArea`` renderers that stack:
 
             .. code-block:: python
@@ -410,7 +411,7 @@ class figure(Plot, GlyphAPI):
         Examples:
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
-            *2016* and *2017*, then the following call to ``hbar_stack`` will
+            *2016* and *2017*, then the following call to ``hbar_stack``
             will create two ``HBar`` renderers that stack:
 
             .. code-block:: python
@@ -454,7 +455,7 @@ class figure(Plot, GlyphAPI):
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
             *2016* and *2017*, then the following call to ``line_stack`` with
-            stackers for the y-coordinates will will create two ``Line``
+            stackers for the y-coordinates will create two ``Line``
             renderers that stack:
 
             .. code-block:: python
@@ -469,18 +470,18 @@ class figure(Plot, GlyphAPI):
                 p.line(y=stack('2016', '2017'), x='x', color='red',  source=source, name='2017')
 
         '''
-        if all(isinstance(val, (list, tuple)) for val in (x,y)):
+        if all(isinstance(val, list | tuple) for val in (x,y)):
             raise ValueError("Only one of x or y may be a list of stackers")
 
         result = []
 
-        if isinstance(y, (list, tuple)):
+        if isinstance(y, list | tuple):
             kw['x'] = x
             for kw in single_stack(y, "y", **kw):
                 result.append(self.line(**kw))
             return result
 
-        if isinstance(x, (list, tuple)):
+        if isinstance(x, list | tuple):
             kw['y'] = y
             for kw in single_stack(x, "x", **kw):
                 result.append(self.line(**kw))
@@ -510,7 +511,7 @@ class figure(Plot, GlyphAPI):
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
             *2016* and *2017*, then the following call to ``hline_stack`` with
-            stackers for the x-coordinates will will create two ``Line``
+            stackers for the x-coordinates will create two ``Line``
             renderers that stack:
 
             .. code-block:: python
@@ -549,7 +550,7 @@ class figure(Plot, GlyphAPI):
         Examples:
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
-            *2016* and *2017*, then the following call to ``varea_stack`` will
+            *2016* and *2017*, then the following call to ``varea_stack``
             will create two ``VArea`` renderers that stack:
 
             .. code-block:: python
@@ -591,7 +592,7 @@ class figure(Plot, GlyphAPI):
         Examples:
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
-            *2016* and *2017*, then the following call to ``vbar_stack`` will
+            *2016* and *2017*, then the following call to ``vbar_stack``
             will create two ``VBar`` renderers that stack:
 
             .. code-block:: python
@@ -633,7 +634,7 @@ class figure(Plot, GlyphAPI):
 
             Assuming a ``ColumnDataSource`` named ``source`` with columns
             *2016* and *2017*, then the following call to ``vline_stack`` with
-            stackers for the y-coordinates will will create two ``Line``
+            stackers for the y-coordinates will create two ``Line``
             renderers that stack:
 
             .. code-block:: python
@@ -703,7 +704,7 @@ class figure(Plot, GlyphAPI):
 
             z (array-like[float] of shape (ny, nx)) :
                 A 2D NumPy array of gridded values to calculate the contours
-                of.  May be a masked array, and any invalid values (``np.inf``
+                of.  It may be a masked array, and any invalid values (``np.inf``
                 or ``np.nan``) will also be masked out.
 
             levels (array-like[float]) :
