@@ -507,8 +507,7 @@ def _bundle_models(custom_models: dict[str, CustomModel]) -> str:
 
     for path in lib_dir.rglob("*.d.ts"):
         s = str(path.relative_to(lib_dir))
-        if s.endswith(".d.ts"):
-            s = s[:-5] # TODO: removesuffix() (Py 3.9+)
+        s = s.removesuffix(".d.ts")
         s = s.replace(os.path.sep, "/")
         known_modules.add(s)
 
@@ -526,14 +525,14 @@ def _bundle_models(custom_models: dict[str, CustomModel]) -> str:
                 if module.endswith(exts):
                     path = mkpath(module)
                     if not exists(path):
-                        raise RuntimeError("no such module: %s" % module)
+                        raise RuntimeError(f"no such module: {module}")
                 else:
                     for ext in exts:
                         path = mkpath(module, ext)
                         if exists(path):
                             break
                     else:
-                        raise RuntimeError("no such module: %s" % module)
+                        raise RuntimeError(f"no such module: {module}")
 
                 impl = FromFile(path)
                 compiled = nodejs_compile(impl.code, lang=impl.lang, file=impl.file)
@@ -556,7 +555,7 @@ def _bundle_models(custom_models: dict[str, CustomModel]) -> str:
             else:
                 index = module + ("" if module.endswith("/") else "/") + "index"
                 if index not in known_modules:
-                    raise RuntimeError("no such module: %s" % module)
+                    raise RuntimeError(f"no such module: {module}")
 
         return resolved
 
@@ -579,8 +578,8 @@ def _bundle_models(custom_models: dict[str, CustomModel]) -> str:
     bare_modules = []
     for i, (module, code, deps) in enumerate(modules):
         for name, ref in deps.items():
-            code = code.replace("""require("%s")""" % name, """require("%s")""" % ref)
-            code = code.replace("""require('%s')""" % name, """require('%s')""" % ref)
+            code = code.replace(f"""require("{name}")""", f"""require("{ref}")""")
+            code = code.replace(f"""require('{name}')""", f"""require('{ref}')""")
         bare_modules.append((module, code))
 
     sep = ",\n"
